@@ -6,6 +6,7 @@ from bokeh.plotting import figure, show, save
 from bokeh.io import output_notebook
 from .basemaps import xyz_to_bokeh
 from .common import *
+from typing import Optional, List, Dict
 
 os.environ["OUTPUT_NOTEBOOK"] = "False"
 basemaps = Box(xyz_to_bokeh(), frozen_box=True)
@@ -14,13 +15,13 @@ basemaps = Box(xyz_to_bokeh(), frozen_box=True)
 class Map:
     def __init__(
         self,
-        center=[10, 0],
-        zoom=2,
-        width=800,
-        height=400,
-        basemap="OpenStreetMap",
-        grid_visible=False,
-        output_notebook=True,
+        center: List[float] = [10, 0],
+        zoom: float = 2,
+        width: float = 800,
+        height: float = 400,
+        basemap: Optional[str] = "OpenStreetMap",
+        grid_visible: bool = False,
+        output_notebook: bool = True,
         **kwargs,
     ):
         if "x_axis_type" not in kwargs:
@@ -60,14 +61,19 @@ class Map:
         self.output_notebook = output_notebook
         self.output_notebook_done = False
 
-    def _repr_mimebundle_(self, **kwargs):
+    def _repr_mimebundle_(self, **kwargs) -> None:
         """Display the bokeh map. Reference: https://ipython.readthedocs.io/en/stable/config/integrating.html#MyObject._repr_mimebundle_"""
         if self.output_notebook and (os.environ["OUTPUT_NOTEBOOK"] == "False"):
             output_notebook()
             os.environ["OUTPUT_NOTEBOOK"] = "True"
         show(self.figure)
 
-    def add_basemap(self, basemap="OpenStreetMap", retina=True, **kwargs):
+    def add_basemap(
+        self,
+        basemap: Optional[str] = "OpenStreetMap",
+        retina: Optional[bool] = True,
+        **kwargs,
+    ) -> None:
         """Adds a basemap to the map.
 
         Args:
@@ -104,8 +110,10 @@ class Map:
                     raise ValueError(
                         f"Basemap {basemap} is not supported. Please choose one from {basemaps.keys()}"
                     )
+        elif basemap is None:
+            raise ValueError("Please specify a valid basemap")
 
-    def add_tile(self, tile, **kwargs):
+    def add_tile(self, tile: str, **kwargs) -> None:
         """Adds a tile to the map.
 
         Args:
@@ -121,14 +129,14 @@ class Map:
 
     def add_cog_layer(
         self,
-        url,
-        attribution="",
-        bands=None,
-        titiler_endpoint=None,
-        cog_args={},
-        fit_bounds=True,
+        url: str,
+        attribution: str = "",
+        bands: Optional[List[str]] = None,
+        titiler_endpoint: Optional[str] = None,
+        cog_args: Dict = {},
+        fit_bounds: bool = True,
         **kwargs,
-    ):
+    ) -> None:
         """Adds a COG TileLayer to the map.
 
         Args:
@@ -155,18 +163,18 @@ class Map:
 
     def add_raster(
         self,
-        source,
-        band=None,
-        palette=None,
-        vmin=None,
-        vmax=None,
-        nodata=None,
-        attribution="",
+        source: str,
+        indexes: Optional[List] = None,
+        colormap: Optional[str] = None,
+        vmin: Optional[float] = None,
+        vmax: Optional[float] = None,
+        nodata: Optional[float] = None,
+        attribution: Optional[str] = "",
+        fit_bounds: bool = True,
         layer_name="Local COG",
-        fit_bounds=True,
         open_args={},
         **kwargs,
-    ):
+    ) -> None:
         """Add a local raster dataset to the map.
             If you are using this function in JupyterHub on a remote server (e.g., Binder, Microsoft Planetary Computer) and
             if the raster does not render properly, try running the following code before calling this function:
@@ -176,10 +184,10 @@ class Map:
 
         Args:
             source (str): The path to the GeoTIFF file or the URL of the Cloud Optimized GeoTIFF.
-            band (int, optional): The band to use. Band indexing starts at 1. Defaults to None.
-            palette (str, optional): The name of the color palette from `palettable` to use when plotting a single band. See https://jiffyclub.github.io/palettable. Default is greyscale
-            vmin (float, optional): The minimum value to use when colormapping the palette when plotting a single band. Defaults to None.
-            vmax (float, optional): The maximum value to use when colormapping the palette when plotting a single band. Defaults to None.
+            indexes (int, optional): The band(s) to use. Band indexing starts at 1. Defaults to None.
+            colormap (str, optional): The name of the colormap from `matplotlib` to use when plotting a single band. See https://matplotlib.org/stable/gallery/color/colormap_reference.html. Default is greyscale.
+            vmin (float, optional): The minimum value to use when colormapping the colormap when plotting a single band. Defaults to None.
+            vmax (float, optional): The maximum value to use when colormapping the colormap when plotting a single band. Defaults to None.
             nodata (float, optional): The value from the band to use to interpret as not valid data. Defaults to None.
             attribution (str, optional): Attribution for the source raster. This defaults to a message about it being a local file. Defaults to None.
             layer_name (str, optional): The layer name to use. Defaults to 'Local COG'.
@@ -193,8 +201,8 @@ class Map:
 
         tile_layer, client = get_local_tile_layer(
             source,
-            band=band,
-            palette=palette,
+            indexes=indexes,
+            colormap=colormap,
             vmin=vmin,
             vmax=vmax,
             nodata=nodata,
@@ -218,22 +226,22 @@ class Map:
 
     def add_stac_layer(
         self,
-        url=None,
-        collection=None,
-        item=None,
-        assets=None,
-        bands=None,
-        titiler_endpoint=None,
-        attribution="",
-        fit_bounds=True,
+        url: str,
+        collection: Optional[str] = None,
+        item: Optional[str] = None,
+        assets: Optional[str] = None,
+        bands: Optional[List[str]] = None,
+        titiler_endpoint: Optional[str] = None,
+        attribution: Optional[str] = "",
+        fit_bounds: Optional[bool] = True,
         open_args={},
         **kwargs,
-    ):
+    ) -> None:
         """Adds a STAC TileLayer to the map.
 
         Args:
             url (str): HTTP URL to a STAC item, e.g., https://canada-spot-ortho.s3.amazonaws.com/canada_spot_orthoimages/canada_spot5_orthoimages/S5_2007/S5_11055_6057_20070622/S5_11055_6057_20070622.json
-            collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
+            collection (str | Optional): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
             item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
             assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
             bands (list): A list of band names, e.g., ["SR_B7", "SR_B5", "SR_B4"]
@@ -258,8 +266,13 @@ class Map:
             self.fit_bounds(stac_bounds(url, collection, item, titiler_endpoint))
 
     def add_gdf(
-        self, gdf, to_crs="epsg:3857", tooltips=None, fit_bounds=True, **kwargs
-    ):
+        self,
+        gdf,
+        to_crs: Optional[str] = "epsg:3857",
+        tooltips: Optional[list] = None,
+        fit_bounds: bool = True,
+        **kwargs,
+    ) -> None:
         """Adds a GeoDataFrame to the map.
 
         Args:
@@ -304,20 +317,20 @@ class Map:
 
     def add_geojson(
         self,
-        filename,
-        encoding="utf-8",
-        read_file_args={},
-        to_crs="epsg:3857",
-        tooltips=None,
-        fit_bounds=True,
+        filename: str,
+        encoding: Optional[str] = "utf-8",
+        read_file_args: Dict = {},
+        to_crs: Optional[str] = "epsg:3857",
+        tooltips: Optional[List] = None,
+        fit_bounds: bool = True,
         **kwargs,
-    ):
+    ) -> None:
         """Adds a GeoJSON file to the map.
 
         Args:
             filename (str): The path to the GeoJSON file. Can be a local file or a URL.
             encoding (str, optional): The encoding of the GeoJSON file. Defaults to "utf-8".
-            read_file_args (dict, optional): A dictionary of arguments to pass to geopandas.read_file. Defaults to {}.
+            read_file_args (Dict, optional): A dictionary of arguments to pass to geopandas.read_file. Defaults to {}.
             to_crs (str, optional): The CRS to use for the GeoDataFrame. Defaults to "epsg:3857".
             tooltips (list, optional): A list of column names to use for tooltips in the form of [(name, @column_name), ...]. Defaults to None, which uses all columns.
             fit_bounds (bool, optional): A flag indicating whether to fit the map bounds to the GeoJSON. Defaults to True.
@@ -336,14 +349,14 @@ class Map:
 
     def add_shp(
         self,
-        filename,
-        encoding="utf-8",
-        read_file_args={},
-        to_crs="epsg:3857",
-        tooltips=None,
-        fit_bounds=True,
+        filename: str,
+        encoding: Optional[str] = "utf-8",
+        read_file_args: Dict = {},
+        to_crs: Optional[str] = "epsg:3857",
+        tooltips: Optional[List] = None,
+        fit_bounds: bool = True,
         **kwargs,
-    ):
+    ) -> None:
         """Adds a shapefile to the map.
 
         Args:
@@ -389,20 +402,20 @@ class Map:
 
     def add_vector(
         self,
-        filename,
-        encoding="utf-8",
-        read_file_args={},
-        to_crs="epsg:3857",
-        tooltips=None,
-        fit_bounds=True,
+        filename: str,
+        encoding: Optional[str] = "utf-8",
+        read_file_args: Dict = {},
+        to_crs: Optional[str] = "epsg:3857",
+        tooltips: Optional[List] = None,
+        fit_bounds: bool = True,
         **kwargs,
-    ):
+    ) -> None:
         """Adds a vector dataset to the map.
 
         Args:
             filename (str): The path to the vector dataset. Can be a local file or a URL.
             encoding (str, optional): The encoding of the vector dataset. Defaults to "utf-8".
-            read_file_args (dict, optional): A dictionary of arguments to pass to geopandas.read_file. Defaults to {}.
+            read_file_args (Dict, optional): A dictionary of arguments to pass to geopandas.read_file. Defaults to {}.
             to_crs (str, optional): The CRS to use for the GeoDataFrame. Defaults to "epsg:3857".
             tooltips (list, optional): A list of column names to use for tooltips in the form of [(name, @column_name), ...]. Defaults to None, which uses all columns.
             fit_bounds (bool, optional): A flag indicating whether to fit the map bounds to the vector dataset. Defaults to True.
@@ -423,7 +436,9 @@ class Map:
             gdf, to_crs=to_crs, tooltips=tooltips, fit_bounds=fit_bounds, **kwargs
         )
 
-    def to_html(self, filename=None, title=None, **kwargs):
+    def to_html(
+        self, filename: Optional[str] = None, title: Optional[str] = None, **kwargs
+    ) -> None:
         """Converts the map to HTML.
 
         Args:
@@ -433,7 +448,7 @@ class Map:
         """
         save(self.figure, filename=filename, title=title, **kwargs)
 
-    def fit_bounds(self, bounds):
+    def fit_bounds(self, bounds: List[float]):
         """Fits the map to the specified bounds in the form of [xmin, ymin, xmax, ymax].
 
         Args:
@@ -447,7 +462,13 @@ class Map:
         self.figure.y_range.start = bounds[1][0]
         self.figure.y_range.end = bounds[1][1]
 
-    def to_streamlit(self, width=800, height=600, use_container_width=True, **kwargs):
+    def to_streamlit(
+        self,
+        width: Optional[int] = 800,
+        height: Optional[int] = 600,
+        use_container_width: bool = True,
+        **kwargs,
+    ) -> None:
         """Displays the map in a Streamlit app.
 
         Args:
@@ -456,7 +477,7 @@ class Map:
             use_container_width (bool, optional): A flag indicating whether to use the full width of the container. Defaults to True.
             **kwargs: Arbitrary keyword arguments for bokeh.plotting.show().
         """
-        import streamlit as st
+        import streamlit as st  # pylint: disable=E0401
 
         self.figure.width = width
         self.figure.height = height
