@@ -4,7 +4,7 @@ import pkg_resources
 
 _pkg_dir = os.path.dirname(pkg_resources.resource_filename("leafmap", "leafmap.py"))
 _datasets_path = os.path.join(_pkg_dir, "examples/datasets.txt")
-_baseurl = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/"
+_baseurl = "https://raw.githubusercontent.com/opengeos/leafmap/master/examples/data/"
 
 with open(_datasets_path) as f:
     _names = [line.strip() for line in f.readlines()]
