@@ -3,11 +3,14 @@ import os
 import sys
 import requests
 import ipywidgets as widgets
+
 import pandas as pd
 from IPython.display import display, HTML
 from .common import *
 from .osm import *
 from . import examples
+from typing import Optional, Union, Dict
+from pandas import DataFrame
 
 try:
     import keplergl
@@ -108,7 +111,13 @@ class Map(keplergl.KeplerGl):
     #     #     bundle["text/html"] = self.display_html()
     #     # return bundle
 
-    def add_geojson(self, in_geojson, layer_name="Untitled", config=None, **kwargs):
+    def add_geojson(
+        self,
+        in_geojson: Union[str, dict],
+        layer_name: Optional[str] = "Untitled",
+        config: Optional[str] = None,
+        **kwargs,
+    ):
         """Adds a GeoJSON file to the map.
 
         Args:
@@ -136,9 +145,9 @@ class Map(keplergl.KeplerGl):
 
                         output = os.path.abspath(output)
                         obj = pyodide.http.open_url(in_geojson)
-                        with open(output, 'w') as fd:
+                        with open(output, "w") as fd:
                             shutil.copyfileobj(obj, fd)
-                        with open(output, 'r') as fd:
+                        with open(output, "r") as fd:
                             data = json.load(fd)
                     else:
                         in_geojson = github_raw_url(in_geojson)
@@ -162,7 +171,13 @@ class Map(keplergl.KeplerGl):
         self.add_data(data, name=layer_name)
         self.load_config(config)
 
-    def add_shp(self, in_shp, layer_name="Untitled", config=None, **kwargs):
+    def add_shp(
+        self,
+        in_shp: str,
+        layer_name: Optional[str] = "Untitled",
+        config: Optional[str] = None,
+        **kwargs,
+    ):
         """Adds a shapefile to the map.
 
         Args:
@@ -204,8 +219,8 @@ class Map(keplergl.KeplerGl):
     def add_gdf(
         self,
         gdf,
-        layer_name="Untitled",
-        config=None,
+        layer_name: Optional[str] = "Untitled",
+        config: Optional[str] = None,
         **kwargs,
     ):
         """Adds a GeoDataFrame to the map.
@@ -223,9 +238,9 @@ class Map(keplergl.KeplerGl):
 
     def add_df(
         self,
-        df,
-        layer_name="Untitled",
-        config=None,
+        df: DataFrame,
+        layer_name: Optional[str] = "Untitled",
+        config: Optional[str] = None,
         **kwargs,
     ):
         """Adds a DataFrame to the map.
@@ -244,9 +259,9 @@ class Map(keplergl.KeplerGl):
 
     def add_csv(
         self,
-        in_csv,
-        layer_name="Untitled",
-        config=None,
+        in_csv: str,
+        layer_name: Optional[str] = "Untitled",
+        config: Optional[str] = None,
         **kwargs,
     ):
         """Adds a CSV to the map.
@@ -263,9 +278,9 @@ class Map(keplergl.KeplerGl):
 
     def add_vector(
         self,
-        filename,
-        layer_name="Untitled",
-        config=None,
+        filename: str,
+        layer_name: Optional[str] = "Untitled",
+        config: Optional[str] = None,
         **kwargs,
     ):
         """Adds any geopandas-supported vector dataset to the map.
@@ -310,9 +325,9 @@ class Map(keplergl.KeplerGl):
 
     def add_kml(
         self,
-        in_kml,
-        layer_name="Untitled",
-        config=None,
+        in_kml: str,
+        layer_name: Optional[str] = "Untitled",
+        config: Optional[str] = None,
         **kwargs,
     ):
         """Adds a KML file to the map.
@@ -348,10 +363,10 @@ class Map(keplergl.KeplerGl):
 
     def add_gdf_from_postgis(
         self,
-        sql,
+        sql: str,
         con,
-        layer_name="Untitled",
-        config=None,
+        layer_name: Optional[str] = "Untitled",
+        config: Optional[str] = None,
         **kwargs,
     ):
         """Reads a PostGIS database and returns data as a GeoDataFrame to be added to the map.
@@ -373,7 +388,12 @@ class Map(keplergl.KeplerGl):
         self.load_config(config)
 
     def static_map(
-        self, width=950, height=600, read_only=False, out_file=None, **kwargs
+        self,
+        width: Optional[int] = 950,
+        height: Optional[int] = 600,
+        read_only: Optional[bool] = False,
+        out_file: Optional[str] = None,
+        **kwargs,
     ):
         """Display a kepler.gl static map in a Jupyter Notebook.
 
@@ -383,6 +403,10 @@ class Map(keplergl.KeplerGl):
             read_only (bool, optional): Whether to hide the side panel to disable map customization. Defaults to False.
             out_file (str, optional): Output html file path. Defaults to None.
         """
+
+        if os.environ.get("USE_MKDOCS") is not None:
+            return
+
         if isinstance(self, keplergl.KeplerGl):
             if out_file is None:
                 if os.environ.get("USE_MKDOCS") is not None:
@@ -402,8 +426,8 @@ class Map(keplergl.KeplerGl):
 
     def to_html(
         self,
-        outfile=None,
-        read_only=False,
+        outfile: Optional[str] = None,
+        read_only: Optional[bool] = False,
         **kwargs,
     ):
         """Saves the map as a HTML file.
@@ -413,6 +437,10 @@ class Map(keplergl.KeplerGl):
             read_only (bool, optional): Whether to hide the side panel to disable map customization. Defaults to False.
 
         """
+
+        if os.environ.get("USE_MKDOCS") is not None:
+            return
+
         try:
             save = True
             if outfile is not None:
@@ -442,7 +470,12 @@ class Map(keplergl.KeplerGl):
             raise Exception(e)
 
     def to_streamlit(
-        self, width=800, height=600, responsive=True, scrolling=False, **kwargs
+        self,
+        width: Optional[int] = 800,
+        height: Optional[int] = 600,
+        responsive: Optional[bool] = True,
+        scrolling: Optional[bool] = False,
+        **kwargs,
     ):
         """Renders `keplergl.KeplerGl` map figure in a Streamlit app.
 
@@ -480,7 +513,7 @@ class Map(keplergl.KeplerGl):
                 "streamlit is not installed. You need to install streamlitusing 'pip install streamlit'. Seehttps://docs.streamlit.io/library/get-started/installation"
             )
 
-    def load_config(self, config=None):
+    def load_config(self, config: Optional[str] = None):
         """Loads a kepler.gl config file.
 
         Args:
@@ -516,6 +549,10 @@ class Map(keplergl.KeplerGl):
             ValueError: The output file extension must be json.
             TypeError: The provided filepath is invalid.
         """
+
+        if os.environ.get("USE_MKDOCS") is not None:
+            return
+
         if isinstance(out_json, str):
             if not out_json.endswith(".json"):
                 raise ValueError("The output file extension must be json.")
