@@ -1,15 +1,17 @@
-"""The module contains functions for downloading OpenStreetMap data. It wraps the geometries module of the osmnx package 
-(see https://osmnx.readthedocs.io/en/stable/osmnx.html#module-osmnx.geometries). Credits to Geoff Boeing, the developer of the osmnx package. 
-Most functions for downloading OpenStreetMap data require tags of map features. The list of commonly used tags can be found at 
-https://wiki.openstreetmap.org/wiki/Map_features 
+"""The module contains functions for downloading OpenStreetMap data. It wraps the geometries module of the osmnx package
+(see https://osmnx.readthedocs.io/en/stable/osmnx.html#module-osmnx.geometries). Credits to Geoff Boeing, the developer of the osmnx package.
+Most functions for downloading OpenStreetMap data require tags of map features. The list of commonly used tags can be found at
+https://wiki.openstreetmap.org/wiki/Map_features
 """
+
 import warnings
 from .common import check_package
+from typing import Optional, Union, Tuple, Dict, List
 
 warnings.filterwarnings("ignore")
 
 
-def osm_gdf_from_address(address, tags, dist=1000):
+def osm_gdf_from_address(address: str, tags: Dict, dist: Optional[int] = 1000):
     """Create GeoDataFrame of OSM entities within some distance N, S, E, W of address.
 
     Args:
@@ -23,11 +25,13 @@ def osm_gdf_from_address(address, tags, dist=1000):
     check_package("osmnx", "https://osmnx.readthedocs.io/en/stable/#installation")
     import osmnx as ox
 
-    gdf = ox.geometries_from_address(address, tags, dist)
+    gdf = ox.features_from_address(address, tags, dist)
     return gdf
 
 
-def osm_shp_from_address(address, tags, filepath, dist=1000):
+def osm_shp_from_address(
+    address: str, tags: Dict, filepath: str, dist: Optional[int] = 1000
+):
     """Download OSM entities within some distance N, S, E, W of address as a shapefile.
 
     Args:
@@ -41,7 +45,9 @@ def osm_shp_from_address(address, tags, filepath, dist=1000):
     gdf.to_file(filepath)
 
 
-def osm_geojson_from_address(address, tags, filepath=None, dist=1000):
+def osm_geojson_from_address(
+    address: str, tags: Dict, filepath: str = None, dist: Optional[int] = 1000
+) -> Dict:
     """Download OSM entities within some distance N, S, E, W of address as a GeoJSON.
 
     Args:
@@ -60,7 +66,12 @@ def osm_geojson_from_address(address, tags, filepath=None, dist=1000):
         return gdf.__geo_interface__
 
 
-def osm_gdf_from_place(query, tags, which_result=None, buffer_dist=None):
+def osm_gdf_from_place(
+    query: Union[str, Dict, List],
+    tags: Dict,
+    which_result: Optional[int] = None,
+    buffer_dist: Optional[float] = None,
+):
     """Create GeoDataFrame of OSM entities within boundaries of geocodable place(s).
 
     Args:
@@ -75,13 +86,20 @@ def osm_gdf_from_place(query, tags, which_result=None, buffer_dist=None):
     check_package("osmnx", "https://osmnx.readthedocs.io/en/stable/#installation")
     import osmnx as ox
 
-    ox.config(use_cache=True, log_console=False)
+    ox.settings.use_cache = True
+    ox.settings.log_console = False
 
-    gdf = ox.geometries_from_place(query, tags, which_result, buffer_dist)
+    gdf = ox.features_from_place(query, tags, which_result, buffer_dist)
     return gdf
 
 
-def osm_shp_from_place(query, tags, filepath, which_result=None, buffer_dist=None):
+def osm_shp_from_place(
+    query: Union[str, Dict, List],
+    tags: Dict,
+    filepath: str,
+    which_result: Optional[int] = None,
+    buffer_dist: Optional[float] = None,
+):
     """Download OSM entities within boundaries of geocodable place(s) as a shapefile.
 
     Args:
@@ -96,8 +114,12 @@ def osm_shp_from_place(query, tags, filepath, which_result=None, buffer_dist=Non
 
 
 def osm_geojson_from_place(
-    query, tags, filepath=None, which_result=None, buffer_dist=None
-):
+    query: Union[str, Dict, List],
+    tags: Dict,
+    filepath: str,
+    which_result: Optional[int] = None,
+    buffer_dist: Optional[float] = None,
+) -> Dict:
     """Download OSM entities within boundaries of geocodable place(s) as a GeoJSON.
 
     Args:
@@ -118,7 +140,9 @@ def osm_geojson_from_place(
         return gdf.__geo_interface__
 
 
-def osm_gdf_from_point(center_point, tags, dist=1000):
+def osm_gdf_from_point(
+    center_point: Tuple[float, float], tags: Dict, dist: Optional[int] = 1000
+):
     """Create GeoDataFrame of OSM entities within some distance N, S, E, W of a point.
 
     Args:
@@ -132,11 +156,16 @@ def osm_gdf_from_point(center_point, tags, dist=1000):
     check_package("osmnx", "https://osmnx.readthedocs.io/en/stable/#installation")
     import osmnx as ox
 
-    gdf = ox.geometries_from_point(center_point, tags, dist)
+    gdf = ox.features_from_point(center_point, tags, dist)
     return gdf
 
 
-def osm_shp_from_point(center_point, tags, filepath, dist=1000):
+def osm_shp_from_point(
+    center_point: Tuple[float, float],
+    tags: Dict,
+    filepath: str,
+    dist: Optional[int] = 1000,
+):
     """Download OSM entities within some distance N, S, E, W of point as a shapefile.
 
     Args:
@@ -149,7 +178,12 @@ def osm_shp_from_point(center_point, tags, filepath, dist=1000):
     gdf.to_file(filepath)
 
 
-def osm_geojson_from_point(center_point, tags, filepath=None, dist=1000):
+def osm_geojson_from_point(
+    center_point: Tuple[float, float],
+    tags: Dict,
+    filepath: str,
+    dist: Optional[int] = 1000,
+) -> Dict:
     """Download OSM entities within some distance N, S, E, W of point as a GeoJSON.
 
     Args:
@@ -168,7 +202,7 @@ def osm_geojson_from_point(center_point, tags, filepath=None, dist=1000):
         return gdf.__geo_interface__
 
 
-def osm_gdf_from_polygon(polygon, tags):
+def osm_gdf_from_polygon(polygon, tags: Dict):
     """Create GeoDataFrame of OSM entities within boundaries of a (multi)polygon.
 
     Args:
@@ -181,11 +215,11 @@ def osm_gdf_from_polygon(polygon, tags):
     check_package("osmnx", "https://osmnx.readthedocs.io/en/stable/#installation")
     import osmnx as ox
 
-    gdf = ox.geometries_from_polygon(polygon, tags)
+    gdf = ox.features_from_polygon(polygon, tags)
     return gdf
 
 
-def osm_shp_from_polygon(polygon, tags, filepath):
+def osm_shp_from_polygon(polygon, tags: Dict, filepath: str):
     """Download OSM entities within boundaries of a (multi)polygon as a shapefile.
 
     Args:
@@ -197,7 +231,9 @@ def osm_shp_from_polygon(polygon, tags, filepath):
     gdf.to_file(filepath)
 
 
-def osm_geojson_from_polygon(polygon, tags, filepath=None):
+def osm_geojson_from_polygon(
+    polygon, tags: Dict, filepath: Optional[str] = None
+) -> Dict:
     """Download OSM entities within boundaries of a (multi)polygon as a GeoJSON.
 
     Args:
@@ -215,7 +251,7 @@ def osm_geojson_from_polygon(polygon, tags, filepath=None):
         return gdf.__geo_interface__
 
 
-def osm_gdf_from_bbox(north, south, east, west, tags):
+def osm_gdf_from_bbox(north: float, south: float, east: float, west: float, tags: Dict):
     """Create a GeoDataFrame of OSM entities within a N, S, E, W bounding box.
 
     Args:
@@ -231,11 +267,13 @@ def osm_gdf_from_bbox(north, south, east, west, tags):
     check_package("osmnx", "https://osmnx.readthedocs.io/en/stable/#installation")
     import osmnx as ox
 
-    gdf = ox.geometries_from_bbox(north, south, east, west, tags)
+    gdf = ox.features_from_bbox(north, south, east, west, tags)
     return gdf
 
 
-def osm_shp_from_bbox(north, south, east, west, tags, filepath):
+def osm_shp_from_bbox(
+    north: float, south: float, east: float, west: float, tags: Dict, filepath: str
+):
     """Download OSM entities within a N, S, E, W bounding box as a shapefile.
 
     Args:
@@ -250,7 +288,14 @@ def osm_shp_from_bbox(north, south, east, west, tags, filepath):
     gdf.to_file(filepath)
 
 
-def osm_geojson_from_bbox(north, south, east, west, tags, filepath=None):
+def osm_geojson_from_bbox(
+    north: float,
+    south: float,
+    east: float,
+    west: float,
+    tags: Dict,
+    filepath: Optional[str] = None,
+):
     """Download OSM entities within a N, S, E, W bounding box as a GeoJSON.
 
     Args:
@@ -271,7 +316,7 @@ def osm_geojson_from_bbox(north, south, east, west, tags, filepath=None):
         return gdf.__geo_interface__
 
 
-def osm_gdf_from_xml(filepath, polygon=None, tags=None):
+def osm_gdf_from_xml(filepath: str, polygon=None, tags: Dict = None):
     """Create a GeoDataFrame of OSM entities in an OSM-formatted XML file.
 
     Args:
@@ -285,15 +330,15 @@ def osm_gdf_from_xml(filepath, polygon=None, tags=None):
     check_package("osmnx", "https://osmnx.readthedocs.io/en/stable/#installation")
     import osmnx as ox
 
-    gdf = ox.geometries_from_xml(filepath, polygon, tags)
+    gdf = ox.features_from_xml(filepath, polygon, tags)
     return gdf
 
 
 def osm_gdf_from_geocode(
-    query,
-    which_result=None,
-    by_osmid=False,
-    buffer_dist=None,
+    query: Union[str, Dict, List],
+    which_result: Optional[int] = None,
+    by_osmid: Optional[bool] = False,
+    buffer_dist: Optional[float] = None,
 ):
     """Retrieves place(s) by name or ID from the Nominatim API as a GeoDataFrame.
 
@@ -316,11 +361,11 @@ def osm_gdf_from_geocode(
 
 
 def osm_shp_from_geocode(
-    query,
-    filepath,
-    which_result=None,
-    by_osmid=False,
-    buffer_dist=None,
+    query: Union[str, Dict, List],
+    filepath: str,
+    which_result: Optional[int] = None,
+    by_osmid: Optional[bool] = False,
+    buffer_dist: Optional[float] = None,
 ):
     """Download place(s) by name or ID from the Nominatim API as a shapefile.
 
@@ -336,11 +381,11 @@ def osm_shp_from_geocode(
 
 
 def osm_geojson_from_geocode(
-    query,
-    filepath=None,
-    which_result=None,
-    by_osmid=False,
-    buffer_dist=None,
+    query: Union[str, Dict, List],
+    filepath: str,
+    which_result: Optional[int] = None,
+    by_osmid: Optional[bool] = False,
+    buffer_dist: Optional[float] = None,
 ):
     """Download place(s) by name or ID from the Nominatim API as a GeoJSON.
 
