@@ -2,10 +2,13 @@ import os
 import numpy as np
 import pandas as pd
 import ipywidgets as widgets
+
 from .basemaps import xyz_to_plotly
 from .common import *
 from .osm import *
 from . import examples
+from typing import Optional, List, Union, Dict, Tuple
+from pandas import DataFrame
 
 try:
     import plotly.express as px
@@ -25,11 +28,11 @@ class Canvas:
     def __init__(
         self,
         map,
-        map_min_width="90%",
-        map_max_width="98%",
-        map_refresh=False,
+        map_min_width: Optional[str] = "90%",
+        map_max_width: Optional[str] = "98%",
+        map_refresh: Optional[bool] = False,
         **kwargs,
-    ):
+    ) -> None:
         """Initialize the Canvas.
 
         Args:
@@ -72,13 +75,18 @@ class Map(go.FigureWidget):
     """The Map class inherits the Plotly FigureWidget class. More info at https://plotly.com/python/figurewidget."""
 
     def __init__(
-        self, center=(20, 0), zoom=1, basemap="open-street-map", height=600, **kwargs
-    ):
+        self,
+        center: Optional[Tuple[float, float]] = (20, 0),
+        zoom: Optional[float] = 1,
+        basemap: Optional[str] = "open-street-map",
+        height: Optional[int] = 600,
+        **kwargs,
+    ) -> None:
         """Initializes a map. More info at https://plotly.com/python/mapbox-layers/
 
         Args:
             center (tuple, optional): Center of the map. Defaults to (20, 0).
-            zoom (int, optional): Zoom level of the map. Defaults to 1.
+            zoom (float, optional): Zoom level of the map. Defaults to 1.
             basemap (str, optional): Can be one of string from "open-street-map", "carto-positron", "carto-darkmatter", "stamen-terrain", "stamen-toner" or "stamen-watercolor" . Defaults to 'open-street-map'.
             height (int, optional): Height of the map. Defaults to 600.
         """
@@ -98,12 +106,12 @@ class Map(go.FigureWidget):
 
     def show(
         self,
-        toolbar=True,
-        map_min_width="91%",
-        map_max_width="98%",
-        refresh=False,
+        toolbar: Optional[bool] = True,
+        map_min_width: Optional[str] = "91%",
+        map_max_width: Optional[str] = "98%",
+        refresh: Optional[bool] = False,
         **kwargs,
-    ):
+    ) -> None:
         """Shows the map.
 
         Args:
@@ -137,7 +145,7 @@ class Map(go.FigureWidget):
         }
         self.show(toolbar=False, config=config)
 
-    def add_controls(self, controls):
+    def add_controls(self, controls: List) -> None:
         """Adds controls to the map.
 
         Args:
@@ -152,7 +160,7 @@ class Map(go.FigureWidget):
 
         self.update_layout(modebar_add=controls)
 
-    def remove_controls(self, controls):
+    def remove_controls(self, controls: List):
         """Removes controls to the map.
 
         Args:
@@ -167,7 +175,7 @@ class Map(go.FigureWidget):
 
         self.update_layout(modebar_remove=controls)
 
-    def set_center(self, lat, lon, zoom=None):
+    def set_center(self, lat: float, lon: float, zoom: Optional[float] = None) -> None:
         """Sets the center of the map.
 
         Args:
@@ -182,7 +190,7 @@ class Map(go.FigureWidget):
             )
         )
 
-    def add_basemap(self, basemap="ROADMAP"):
+    def add_basemap(self, basemap: Optional[str] = "ROADMAP") -> None:
         """Adds a basemap to the map.
 
         Args:
@@ -198,7 +206,7 @@ class Map(go.FigureWidget):
         layers = list(self.layout.mapbox.layers) + [basemaps[basemap]]
         self.update_layout(mapbox_layers=layers)
 
-    def remove_basemap(self, name):
+    def remove_basemap(self, name: str) -> None:
         """Removes a basemap from the map.
 
         Args:
@@ -208,7 +216,7 @@ class Map(go.FigureWidget):
         layers = [layer for layer in layers if layer["name"] != name]
         self.layout.mapbox.layers = layers
 
-    def add_mapbox_layer(self, style, access_token=None):
+    def add_mapbox_layer(self, style: Union[str, Dict], access_token=None) -> None:
         """Adds a mapbox layer to the map.
 
         Args:
@@ -223,7 +231,7 @@ class Map(go.FigureWidget):
             mapbox_style=style, mapbox_layers=[], mapbox_accesstoken=access_token
         )
 
-    def add_layer(self, layer, name=None, **kwargs):
+    def add_layer(self, layer, name: Optional[str] = None, **kwargs):
         """Adds a layer to the map.
 
         Args:
@@ -234,7 +242,7 @@ class Map(go.FigureWidget):
             layer.name = name
         self.add_trace(layer, **kwargs)
 
-    def remove_layer(self, name):
+    def remove_layer(self, name: str) -> None:
         """Removes a layer from the map.
 
         Args:
@@ -247,7 +255,7 @@ class Map(go.FigureWidget):
                 layer for layer in self.layout.mapbox.layers if layer["name"] != name
             ]
 
-    def clear_layers(self, clear_basemap=False):
+    def clear_layers(self, clear_basemap: Optional[bool] = False):
         """Clears all layers from the map.
 
         Args:
@@ -259,7 +267,7 @@ class Map(go.FigureWidget):
             if len(self.data) > 1:
                 self.data = self.data[:1]
 
-    def get_layers(self):
+    def get_layers(self) -> Dict:
         """Returns a dictionary of all layers in the map.
         Returns:
             dict: A dictionary of all layers in the map.
@@ -276,7 +284,7 @@ class Map(go.FigureWidget):
 
         return layers
 
-    def get_tile_layers(self):
+    def get_tile_layers(self) -> Dict:
         """Returns a dictionary of tile layers in the map.
 
         Returns:
@@ -291,7 +299,7 @@ class Map(go.FigureWidget):
 
         return layers
 
-    def get_data_layers(self):
+    def get_data_layers(self) -> Dict:
         """Returns a dictionary of data layers in the map.
 
         Returns:
@@ -306,7 +314,7 @@ class Map(go.FigureWidget):
 
         return layers
 
-    def find_layer_index(self, name):
+    def find_layer_index(self, name: str) -> int:
         """Finds the index of a layer.
 
         Args:
@@ -325,7 +333,7 @@ class Map(go.FigureWidget):
 
         return None
 
-    def set_layer_visibility(self, name, show=True):
+    def set_layer_visibility(self, name: str, show: Optional[bool] = True) -> None:
         """Sets the visibility of a layer.
 
         Args:
@@ -342,7 +350,7 @@ class Map(go.FigureWidget):
         else:
             print(f"Layer {name} not found.")
 
-    def set_layer_opacity(self, name, opacity=1):
+    def set_layer_opacity(self, name: str, opacity: Optional[float] = 1) -> None:
         """Sets the visibility of a layer.
 
         Args:
@@ -365,12 +373,12 @@ class Map(go.FigureWidget):
 
     def add_tile_layer(
         self,
-        url,
-        name="TileLayer",
-        attribution="",
-        opacity=1.0,
+        url: str,
+        name: Optional[str] = "TileLayer",
+        attribution: Optional[str] = "",
+        opacity: Optional[float] = 1.0,
         **kwargs,
-    ):
+    ) -> None:
         """Adds a TileLayer to the map.
 
         Args:
@@ -393,18 +401,18 @@ class Map(go.FigureWidget):
 
     def add_cog_layer(
         self,
-        url,
-        name="Untitled",
-        attribution="",
-        opacity=1.0,
-        bands=None,
-        titiler_endpoint=None,
+        url: str,
+        name: Optional[str] = "Untitled",
+        attribution: Optional[str] = "",
+        opacity: Optional[float] = 1.0,
+        bands: Optional[List] = None,
+        titiler_endpoint: Optional[str] = None,
         **kwargs,
-    ):
+    ) -> None:
         """Adds a COG TileLayer to the map.
 
         Args:
-            url (str): The URL of the COG tile layer, e.g., 'https://opendata.digitalglobe.com/events/california-fire-2020/pre-event/2018-02-16/pine-gulch-fire20/1030010076004E00.tif'
+            url (str): The URL of the COG tile layer, e.g., 'https://github.com/opengeos/data/releases/download/raster/Libya-2023-07-01.tif'
             name (str, optional): The layer name to use for the layer. Defaults to 'Untitled'.
             attribution (str, optional): The attribution to use. Defaults to ''.
             opacity (float, optional): The opacity of the layer. Defaults to 1.
@@ -422,17 +430,17 @@ class Map(go.FigureWidget):
 
     def add_stac_layer(
         self,
-        url=None,
-        collection=None,
-        item=None,
-        assets=None,
-        bands=None,
-        titiler_endpoint=None,
-        name="STAC Layer",
-        attribution="",
-        opacity=1.0,
+        url: str = None,
+        collection: str = None,
+        items: str = None,
+        assets: str = None,
+        bands: List = None,
+        titiler_endpoint: Optional[str] = None,
+        name: Optional[str] = "STAC Layer",
+        attribution: Optional[str] = "",
+        opacity: Optional[float] = 1.0,
         **kwargs,
-    ):
+    ) -> None:
         """Adds a STAC TileLayer to the map.
 
         Args:
@@ -447,21 +455,21 @@ class Map(go.FigureWidget):
             opacity (float, optional): The opacity of the layer. Defaults to 1.
         """
         tile_url = stac_tile(
-            url, collection, item, assets, bands, titiler_endpoint, **kwargs
+            url, collection, items, assets, bands, titiler_endpoint, **kwargs
         )
-        center = stac_center(url, collection, item, titiler_endpoint)
+        center = stac_center(url, collection, items, titiler_endpoint)
         self.add_tile_layer(tile_url, name, attribution, opacity)
         self.set_center(lon=center[0], lat=center[1], zoom=10)
 
     def add_mosaic_layer(
         self,
-        url,
-        titiler_endpoint=None,
-        name="Mosaic Layer",
-        attribution="",
-        opacity=1.0,
+        url: str,
+        titiler_endpoint: Optional[str] = None,
+        name: Optional[str] = "Mosaic Layer",
+        attribution: Optional[str] = "",
+        opacity: Optional[float] = 1.0,
         **kwargs,
-    ):
+    ) -> None:
         """Adds a STAC TileLayer to the map.
 
         Args:
@@ -478,14 +486,14 @@ class Map(go.FigureWidget):
 
     def add_planet_by_month(
         self,
-        year=2016,
-        month=1,
-        api_key=None,
-        token_name="PLANET_API_KEY",
-        name=None,
-        attribution="",
-        opacity=1.0,
-    ):
+        year: Optional[int] = 2016,
+        month: Optional[int] = 1,
+        api_key: Optional[str] = None,
+        token_name: Optional[str] = "PLANET_API_KEY",
+        name: Optional[str] = None,
+        attribution: str = "",
+        opacity: Optional[float] = 1.0,
+    ) -> None:
         """Adds Planet global mosaic by month to the map. To get a Planet API key, see https://developers.planet.com/quickstart/apis/
 
         Args:
@@ -506,14 +514,14 @@ class Map(go.FigureWidget):
 
     def add_planet_by_quarter(
         self,
-        year=2016,
-        quarter=1,
-        api_key=None,
-        token_name="PLANET_API_KEY",
-        name=None,
-        attribution="",
-        opacity=1.0,
-    ):
+        year: Optional[int] = 2016,
+        quarter: Optional[int] = 1,
+        api_key: Optional[str] = None,
+        token_name: Optional[str] = "PLANET_API_KEY",
+        name: Optional[str] = None,
+        attribution: str = "",
+        opacity: Optional[float] = 1.0,
+    ) -> None:
         """Adds Planet global mosaic by month to the map. To get a Planet API key, see https://developers.planet.com/quickstart/apis/
 
         Args:
@@ -532,7 +540,15 @@ class Map(go.FigureWidget):
             tile_url, name=name, attribution=attribution, opacity=opacity
         )
 
-    def save(self, file, format=None, width=None, height=None, scale=None, **kwargs):
+    def save(
+        self,
+        file: str,
+        format: Optional[str] = None,
+        width: Optional[int] = None,
+        height: Optional[int] = None,
+        scale: Optional[int] = None,
+        **kwargs,
+    ) -> None:
         """Convert a map to a static image and write it to a file or writeable object
 
         Args:
@@ -547,12 +563,17 @@ class Map(go.FigureWidget):
         )
 
     def add_choropleth_map(
-        self, data, name=None, z=None, colorscale="Viridis", **kwargs
-    ):
+        self,
+        data: str,
+        name: Optional[str] = None,
+        z: Optional[str] = None,
+        colorscale: Optional[str] = "Viridis",
+        **kwargs,
+    ) -> None:
         """Adds a choropleth map to the map.
 
         Args:
-            data (str): File path to vector data, e.g., https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/countries.geojson
+            data (str): File path to vector data, e.g., https://raw.githubusercontent.com/opengeos/leafmap/master/examples/data/countries.geojson
             name (str, optional): Name of the layer. Defaults to None.
             z (str, optional): Z value of the data. Defaults to None.
             colorscale (str, optional): Color scale of the data. Defaults to "Viridis".
@@ -573,7 +594,7 @@ class Map(go.FigureWidget):
             **kwargs,
         )
 
-    def add_scatter_plot_demo(self, **kwargs):
+    def add_scatter_plot_demo(self, **kwargs) -> None:
         """Adds a scatter plot to the map."""
         lons = np.random.random(1000) * 360.0
         lats = np.random.random(1000) * 180.0 - 90.0
@@ -584,15 +605,15 @@ class Map(go.FigureWidget):
 
     def add_heatmap(
         self,
-        data,
-        latitude="latitude",
-        longitude="longitude",
-        z="value",
-        radius=10,
-        colorscale=None,
-        name="Heat map",
+        data: Union[str, DataFrame],
+        latitude: Optional[str] = "latitude",
+        longitude: Optional[str] = "longitude",
+        z: Optional[str] = "value",
+        radius: Optional[int] = 10,
+        colorscale: Optional[str] = None,
+        name: Optional[str] = "Heat map",
         **kwargs,
-    ):
+    ) -> None:
         """Adds a heat map to the map. Reference: https://plotly.com/python/mapbox-density-heatmaps
 
         Args:
@@ -624,7 +645,7 @@ class Map(go.FigureWidget):
         )
         self.add_trace(heatmap)
 
-    def add_heatmap_demo(self, **kwargs):
+    def add_heatmap_demo(self, **kwargs) -> None:
         """Adds a heatmap to the map."""
         quakes = pd.read_csv(
             "https://raw.githubusercontent.com/plotly/datasets/master/earthquakes-23k.csv"
@@ -638,17 +659,17 @@ class Map(go.FigureWidget):
             **kwargs,
         )
 
-        self.add_basemap("Stamen.Terrain")
+        self.add_basemap("Esri.WorldTopoMap")
         self.add_trace(heatmap)
 
     def add_gdf_demo(
         self,
         gdf,
-        label_col,
-        color_col,
-        color_continuous_scale="Viridis",
+        label_col: Optional[str],
+        color_col: Optional[str],
+        color_continuous_scale: Optional[str] = "Viridis",
         **kwargs,
-    ):
+    ) -> None:
         check_package("geopandas", "https://geopandas.org")
         import geopandas as gpd
 
@@ -681,14 +702,14 @@ class Map(go.FigureWidget):
     def add_gdf(
         self,
         gdf,
-        label_col=None,
-        color_col=None,
+        label_col: Optional[str] = None,
+        color_col: Optional[str] = None,
         labels=None,
-        opacity=1.0,
-        zoom=None,
-        color_continuous_scale="Viridis",
+        opacity: Optional[float] = 1.0,
+        zoom: Optional[int] = None,
+        color_continuous_scale: Optional[str] = "Viridis",
         **kwargs,
-    ):
+    ) -> None:
         """Adds a GeoDataFrame to the map.
         Args:
             gdf (GeoDataFrame): A GeoDataFrame.
@@ -737,7 +758,13 @@ class Map(go.FigureWidget):
         self.add_traces(fig.data)
         self.set_center(center_lat, center_lon, zoom)
 
-    def add_geojson_layer(self, geojson_in, name, color="blue", opacity=1):
+    def add_geojson_layer(
+        self,
+        geojson_in: Union[str, Dict],
+        name: str,
+        color: Optional[str] = "blue",
+        opacity: Optional[float] = 1,
+    ) -> None:
         """Prepare proper and give style for different type of Geometry
 
         Args:
@@ -775,7 +802,14 @@ class Map(go.FigureWidget):
 
         self.add_geojson(data, name, type, color, opacity)
 
-    def add_geojson(self, data, name, type, color, opacity):
+    def add_geojson(
+        self,
+        data: Dict,
+        name: str,
+        type: Optional[str],
+        color: Optional[str],
+        opacity: Optional[float],
+    ) -> None:
         """Add layers to the Map
 
         Args:
@@ -801,7 +835,7 @@ class Map(go.FigureWidget):
         self.update_layout(mapbox={"layers": tuple(existing_layers)})
 
 
-def fix_widget_error():
+def fix_widget_error() -> None:
     """
     Fix FigureWidget - 'mapbox._derived' Value Error.
     Adopted from: https://github.com/plotly/plotly.py/issues/2570#issuecomment-738735816
