@@ -22,6 +22,7 @@ class TestFoliumap(unittest.TestCase):
     def test_add_basemap(self):
         """Check basemaps"""
         m = leafmap.Map()
+        leafmap.set_api_key("API-KEY")
         m.add_basemap("TERRAIN")
         out_str = m.to_html()
         assert "Google Terrain" in out_str
@@ -29,7 +30,7 @@ class TestFoliumap(unittest.TestCase):
     # def test_add_cog_layer(self):
     #     """Check COG layer"""
     #     m = leafmap.Map()
-    #     url = "https://opendata.digitalglobe.com/events/california-fire-2020/pre-event/2018-02-16/pine-gulch-fire20/1030010076004E00.tif"
+    #     url = "https://github.com/opengeos/data/releases/download/raster/Libya-2023-07-01.tif"
     #     m.add_cog_layer(url, name="Fire (pre-event)")
     #     out_str = m.to_html()
     #     assert "Fire (pre-event)" in out_str
@@ -38,7 +39,7 @@ class TestFoliumap(unittest.TestCase):
     #     """Check COG mosaic"""
     #     m = leafmap.Map()
     #     links = [
-    #         "https://opendata.digitalglobe.com/events/california-fire-2020/pre-event/2018-02-16/pine-gulch-fire20/1030010076004E00.tif",
+    #         "https://github.com/opengeos/data/releases/download/raster/Libya-2023-07-01.tif",
     #         "https://opendata.digitalglobe.com/events/california-fire-2020/pre-event/2018-08-18/pine-gulch-fire20/1040010041D3B300.tif",
     #     ]
 
@@ -47,15 +48,15 @@ class TestFoliumap(unittest.TestCase):
     #     assert "COG mosaic" in out_str
     #     assert "MAXAR" in out_str
 
-    def test_add_colorbar(self):
-        """Check colorbar"""
-        m = leafmap.Map()
-        colors = ["006633", "E5FFCC", "662A00", "D8D8D8", "F5F5F5"]
-        vmin = 0
-        vmax = 4000
-        m.add_colorbar(colors=colors, vmin=vmin, vmax=vmax, caption="Elevation")
-        out_str = m.to_html()
-        assert "Elevation" in out_str
+    # def test_add_colorbar(self):
+    #     """Check colorbar"""
+    #     m = leafmap.Map()
+    #     colors = ["006633", "E5FFCC", "662A00", "D8D8D8", "F5F5F5"]
+    #     vmin = 0
+    #     vmax = 4000
+    #     m.add_colorbar(colors=colors, vmin=vmin, vmax=vmax, caption="Elevation")
+    #     out_str = m.to_html()
+    #     assert "Elevation" in out_str
 
     # @patch("matplotlib.pyplot.show")
     # def test_add_colormap(self, mock_show):
@@ -70,7 +71,7 @@ class TestFoliumap(unittest.TestCase):
         """Check GeoDataFrame"""
         m = leafmap.Map()
         gdf = gpd.read_file(
-            "https://github.com/giswqs/leafmap/raw/master/examples/data/cable_geo.geojson"
+            "https://github.com/opengeos/leafmap/raw/master/examples/data/cable_geo.geojson"
         )
         m.add_gdf(gdf, layer_name="Cable lines")
         out_str = m.to_html()
@@ -107,7 +108,7 @@ class TestFoliumap(unittest.TestCase):
     def test_add_geojson(self):
         """Check GeoJSON"""
         m = leafmap.Map()
-        in_geojson = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/cable_geo.geojson"
+        in_geojson = "https://raw.githubusercontent.com/opengeos/leafmap/master/examples/data/cable_geo.geojson"
         m.add_geojson(in_geojson, layer_name="Cable lines")
         out_str = m.to_html()
         assert "Cable lines" in out_str
@@ -115,7 +116,7 @@ class TestFoliumap(unittest.TestCase):
     def test_add_heatmap(self):
         """Check heat map"""
         m = leafmap.Map()
-        in_csv = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/world_cities.csv"
+        in_csv = "https://raw.githubusercontent.com/opengeos/leafmap/master/examples/data/world_cities.csv"
         m.add_heatmap(
             in_csv,
             latitude="latitude",
@@ -130,7 +131,7 @@ class TestFoliumap(unittest.TestCase):
     def test_add_kml(self):
         """Check KML"""
         m = leafmap.Map()
-        in_kml = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/us_states.kml"
+        in_kml = "https://raw.githubusercontent.com/opengeos/leafmap/master/examples/data/us_states.kml"
         m.add_kml(in_kml, layer_name="US States KML")
         out_str = m.to_html()
         assert "US States KML" in out_str
@@ -152,6 +153,15 @@ class TestFoliumap(unittest.TestCase):
         out_str = m.to_html()
         assert "NLCD" in out_str
 
+    def test_add_wms_legend(self):
+        """Check add of wms legend based on url"""
+        m = leafmap.Map()
+        url = "https://www.mrlc.gov/geoserver/mrlc_display/NLCD_2016_Land_Cover_L48/wms?REQUEST=GetLegendGraphic&FORMAT=image/png&LAYER=NLCD_2016_Land_Cover_L48"
+        m.add_wms_legend(url=url)
+        out_str = m.to_html()
+
+        assert "GetLegendGraphic" in out_str
+
     # def test_add_marker_cluster(self):
     #     """Check marker cluster"""
     #     with self.assertRaises(NotImplementedError):
@@ -168,34 +178,34 @@ class TestFoliumap(unittest.TestCase):
             out_str = m.to_html()
             assert "150px" in out_str
 
-    def test_add_osm_from_address(self):
-        """Check OSM data from address"""
-        m = leafmap.Map()
-        m.add_osm_from_address(
-            address="New York City",
-            tags={"amenity": "bar"},
-            dist=1500,
-            layer_name="NYC bars",
-        )
-        out_str = m.to_html()
-        assert "NYC bars" in out_str
+    # def test_add_osm_from_address(self):
+    #     """Check OSM data from address"""
+    #     m = leafmap.Map()
+    #     m.add_osm_from_address(
+    #         address="New York City",
+    #         tags={"amenity": "bar"},
+    #         dist=1500,
+    #         layer_name="NYC bars",
+    #     )
+    #     out_str = m.to_html()
+    #     assert "NYC bars" in out_str
 
-    def test_add_osm_from_bbox(self):
-        """Check OSM data from bbox"""
-        m = leafmap.Map()
-        north, south, east, west = 40.7551, 40.7454, -73.9738, -73.9965
-        m.add_osm_from_bbox(
-            north, south, east, west, tags={"amenity": "bar"}, layer_name="NYC bars"
-        )
-        out_str = m.to_html()
-        assert "NYC bars" in out_str
+    # def test_add_osm_from_bbox(self):
+    #     """Check OSM data from bbox"""
+    #     m = leafmap.Map()
+    #     north, south, east, west = 40.7551, 40.7454, -73.9738, -73.9965
+    #     m.add_osm_from_bbox(
+    #         north, south, east, west, tags={"amenity": "bar"}, layer_name="NYC bars"
+    #     )
+    #     out_str = m.to_html()
+    #     assert "NYC bars" in out_str
 
-    def test_add_osm_from_geocode(self):
-        """Check OSM data from geocode"""
-        m = leafmap.Map()
-        m.add_osm_from_geocode("New York City", layer_name="NYC")
-        out_str = m.to_html()
-        assert "NYC" in out_str
+    # def test_add_osm_from_geocode(self):
+    #     """Check OSM data from geocode"""
+    #     m = leafmap.Map()
+    #     m.add_osm_from_geocode("New York City", layer_name="NYC")
+    #     out_str = m.to_html()
+    #     assert "NYC" in out_str
 
     # def test_add_osm_from_place(self):
     #     """Check OSM data from place"""
@@ -206,43 +216,43 @@ class TestFoliumap(unittest.TestCase):
     #     out_str = m.to_html()
     #     assert "Los Angeles, CA" in out_str
 
-    def test_add_osm_from_point(self):
-        """Check OSM data from point"""
-        m = leafmap.Map()
-        m.add_osm_from_point(
-            center_point=(46.7808, -96.0156),
-            tags={"natural": "water"},
-            dist=10000,
-            layer_name="Lakes",
-        )
-        out_str = m.to_html()
-        assert "Lakes" in out_str
+    # def test_add_osm_from_point(self):
+    #     """Check OSM data from point"""
+    #     m = leafmap.Map()
+    #     m.add_osm_from_point(
+    #         center_point=(46.7808, -96.0156),
+    #         tags={"natural": "water"},
+    #         dist=10000,
+    #         layer_name="Lakes",
+    #     )
+    #     out_str = m.to_html()
+    #     assert "Lakes" in out_str
 
-    def test_add_osm_from_polygon(self):
-        """Check OSM data from polygon"""
-        from shapely.geometry import Polygon
+    # def test_add_osm_from_polygon(self):
+    #     """Check OSM data from polygon"""
+    #     from shapely.geometry import Polygon
 
-        m = leafmap.Map()
-        polygon = Polygon(
-            [
-                [-73.996784, 40.725046],
-                [-73.996784, 40.734282],
-                [-73.983052, 40.734282],
-                [-73.983052, 40.725046],
-                [-73.996784, 40.725046],
-            ]
-        )
-        tags = {"building": True}
-        m.add_osm_from_polygon(polygon, tags, layer_name="NYC Buildings")
-        out_str = m.to_html()
-        assert "NYC Buildings" in out_str
+    #     m = leafmap.Map()
+    #     polygon = Polygon(
+    #         [
+    #             [-73.996784, 40.725046],
+    #             [-73.996784, 40.734282],
+    #             [-73.983052, 40.734282],
+    #             [-73.983052, 40.725046],
+    #             [-73.996784, 40.725046],
+    #         ]
+    #     )
+    #     tags = {"building": True}
+    #     m.add_osm_from_polygon(polygon, tags, layer_name="NYC Buildings")
+    #     out_str = m.to_html()
+    #     assert "NYC Buildings" in out_str
 
-    def test_add_osm_from_view(self):
-        """Check OSM data from view"""
-        m = leafmap.Map()
-        m.add_osm_from_view(tags={"building": True}, layer_name="NYC buildings")
-        out_str = m.to_html()
-        assert "NYC buildings" not in out_str
+    # def test_add_osm_from_view(self):
+    #     """Check OSM data from view"""
+    #     m = leafmap.Map()
+    #     m.add_osm_from_view(tags={"building": True}, layer_name="NYC buildings")
+    #     out_str = m.to_html()
+    #     assert "NYC buildings" not in out_str
 
     def test_add_planet_by_month(self):
         """Check Planet monthly imagery"""
@@ -262,26 +272,16 @@ class TestFoliumap(unittest.TestCase):
         """Check adding point layer"""
         with self.assertRaises(NotImplementedError):
             m = leafmap.Map()
-            url = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/us_cities.geojson"
+            url = "https://raw.githubusercontent.com/opengeos/leafmap/master/examples/data/us_cities.geojson"
             m.add_point_layer(url, popup=["name", "pop_max"], layer_name="US Cities")
             out_str = m.to_html()
             assert "US Cities" in out_str
 
-    # def test_add_raster(self):
-    #     """Check loading raster data"""
-    #     with self.assertRaises(NotImplementedError):
-    #         m = leafmap.Map()
-    #         landsat_url = "https://drive.google.com/file/d/1vRkAWQYsLWCi6vcTMk8vLxoXMFbdMFn8/view?usp=sharing"
-    #         leafmap.download_from_gdrive(landsat_url, "dem.tif", unzip=False)
-    #         m.add_raster("dem.tif", colormap="terrain", layer_name="DEM")
-    #         out_str = m.to_html()
-    #         assert "DEM" in out_str
-
     # def test_add_shp(self):
     #     """Check adding shapefile"""
     #     m = leafmap.Map()
     #     in_shp = (
-    #         "https://github.com/giswqs/leafmap/raw/master/examples/data/countries.zip"
+    #         "https://github.com/opengeos/leafmap/raw/master/examples/data/countries.zip"
     #     )
     #     m.add_shp(in_shp, layer_name="Countries")
     #     out_str = m.to_html()
@@ -318,7 +318,7 @@ class TestFoliumap(unittest.TestCase):
     def test_add_vector(self):
         """Check adding vector"""
         m = leafmap.Map()
-        url = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/countries.geojson"
+        url = "https://raw.githubusercontent.com/opengeos/leafmap/master/examples/data/countries.geojson"
         m.add_vector(
             url,
             layer_name="Countries",
@@ -345,7 +345,7 @@ class TestFoliumap(unittest.TestCase):
         """Check adding xy data"""
         with self.assertRaises(NotImplementedError):
             m = leafmap.Map()
-            in_csv = "https://raw.githubusercontent.com/giswqs/data/main/world/world_cities.csv"
+            in_csv = "https://raw.githubusercontent.com/opengeos/data/main/world/world_cities.csv"
             m.add_xy_data(
                 in_csv, x="longitude", y="latitude", layer_name="World Cities"
             )
@@ -355,9 +355,7 @@ class TestFoliumap(unittest.TestCase):
     def test_add_points_from_xy(self):
         "Check adding point data"
         m = leafmap.Map()
-        in_csv = (
-            "https://raw.githubusercontent.com/giswqs/data/main/world/world_cities.csv"
-        )
+        in_csv = "https://raw.githubusercontent.com/opengeos/data/main/world/world_cities.csv"
         m.add_points_from_xy(
             in_csv, x="longitude", y="latitude", layer_name="World Cities"
         )
@@ -467,7 +465,7 @@ class TestFoliumap(unittest.TestCase):
         """Check zoom to GeoDataFrame"""
         m = leafmap.Map()
         gdf = gpd.read_file(
-            "https://github.com/giswqs/leafmap/raw/master/examples/data/cable_geo.geojson"
+            "https://github.com/opengeos/leafmap/raw/master/examples/data/cable_geo.geojson"
         )
         m.zoom_to_gdf(gdf)
         out_str = m.to_html()
